==> openshift-model-operatorhub-6.4.0-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1alpha1/SpecDescriptorFluent.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.util.ArrayList;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;
import java.util.function.Predicate;

 /**
  * Generated
  */
public interface SpecDescriptorFluent<A extends SpecDescriptorFluent<A>> extends Fluent<A>{
  public String getDescription();
  public A withDescription(String description);
  public Boolean hasDescription();
  public String getDisplayName();
  public A withDisplayName(String displayName);
  public Boolean hasDisplayName();
  public String getPath();
  public A withPath(String path);
  public Boolean hasPath();
  public String getValue();
  public A withValue(String value);
  public Boolean hasValue();
  public A addToXDescriptors(Integer index,String item);
  public A setToXDescriptors(Integer index,String item);
  public A addToXDescriptors(java.lang.String... items);
  public A addAllToXDescriptors(Collection<String> items);
  public A removeFromXDescriptors(java.lang.String... items);
  public A removeAllFromXDescriptors(Collection<String> items);
  public List<String> getXDescriptors();
  public String getXDescriptor(Integer index);
  public String getFirstXDescriptor();
  public String getLastXDescriptor();
  public String getMatchingXDescriptor(Predicate<String> predicate);
  public Boolean hasMatchingXDescriptor(Predicate<String> predicate);
  public A withXDescriptors(List<String> xDescriptors);
  public A withXDescriptors(java.lang.String... xDescriptors);
  public Boolean hasXDescriptors();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  
}

==> openshift-model-operatorhub-6.7.0-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1alpha1/SpecDescriptorFluent.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface SpecDescriptorFluent<A extends SpecDescriptorFluent<A>> extends Fluent<A>{
  public String getDescription();
  public A withDescription(String description);
  public Boolean hasDescription();
  public String getDisplayName();
  public A withDisplayName(String displayName);
  public Boolean hasDisplayName();
  public String getPath();
  public A withPath(String path);
  public Boolean hasPath();
  public String getValue();
  public A withValue(String value);
  public Boolean hasValue();
  public A addToXDescriptors(int index,String item);
  public A setToXDescriptors(int index,String item);
  public A addToXDescriptors(java.lang.String... items);
  public A addAllToXDescriptors(Collection<String> items);
  public A removeFromXDescriptors(java.lang.String... items);
  public A removeAllFromXDescriptors(Collection<String> items);
  public List<String> getXDescriptors();
  public String getXDescriptor(int index);
  public String getFirstXDescriptor();
  public String getLastXDescriptor();
  public String getMatchingXDescriptor(Predicate<String> predicate);
  public Boolean hasMatchingXDescriptor(Predicate<String> predicate);
  public A withXDescriptors(List<String> xDescriptors);
  public A withXDescriptors(java.lang.String... xDescriptors);
  public Boolean hasXDescriptors();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  
}
